@@ -121,6 +121,10 @@ class TestCase(object):
         self.Model.metadata.drop_all(self.connection)
 
     def teardown_method(self, method):
+        self.session.rollback()
+        uow_leaks = versioning_manager.units_of_work
+        session_map_leaks = versioning_manager.session_connection_map
+
         remove_versioning()
         QueryPool.queries = []
         versioning_manager.reset()
@@ -131,6 +135,9 @@ class TestCase(object):
         self.engine.dispose()
         self.connection.close()
 
+        assert not uow_leaks
+        assert not session_map_leaks
+
     def create_models(self):
         class Article(self.Model):
             __tablename__ = 'article'
